@@ -302,6 +302,29 @@ def test_main_json_failed():
         main()
 
 
+@freeze_time('2019-07-26')
+def test_main_null_and_array():
+    with TemporaryDirectory() as output_dir:
+        output_file: Path = Path(output_dir) / 'output.py'
+        return_code: Exit = main(
+            [
+                '--input',
+                str(JSON_SCHEMA_DATA_PATH / 'null_and_array.json'),
+                '--output',
+                str(output_file),
+                '--input-file-type',
+                'jsonschema',
+            ]
+        )
+        assert return_code == Exit.OK
+        assert (
+            output_file.read_text()
+            == (EXPECTED_MAIN_PATH / 'main_null_and_array' / 'output.py').read_text()
+        )
+    with pytest.raises(SystemExit):
+        main()
+
+
 @freeze_time('2019-07-26')
 def test_main_yaml():
     with TemporaryDirectory() as output_dir:
